summaryrefslogtreecommitdiffstats
path: root/kmail/treebase.cpp
diff options
context:
space:
mode:
authortpearson <tpearson@283d02a7-25f6-0310-bc7c-ecb5cbfe19da>2011-08-10 22:19:39 +0000
committertpearson <tpearson@283d02a7-25f6-0310-bc7c-ecb5cbfe19da>2011-08-10 22:19:39 +0000
commit36a36a5c1015aa0d03f4515c401e907ddb9d6291 (patch)
tree0212ba6d2c749043134005a41f2bd0379619d40f /kmail/treebase.cpp
parent4c6f8d69e2d1501837affb472c4eb8fec4462240 (diff)
downloadtdepim-36a36a5c1015aa0d03f4515c401e907ddb9d6291.tar.gz
tdepim-36a36a5c1015aa0d03f4515c401e907ddb9d6291.zip
rename the following methods:
tqparent parent tqmask mask git-svn-id: svn://anonsvn.kde.org/home/kde/branches/trinity/kdepim@1246260 283d02a7-25f6-0310-bc7c-ecb5cbfe19da
Diffstat (limited to 'kmail/treebase.cpp')
-rw-r--r--kmail/treebase.cpp24
1 files changed, 12 insertions, 12 deletions
diff --git a/kmail/treebase.cpp b/kmail/treebase.cpp
index 137dbfcd..19aff315 100644
--- a/kmail/treebase.cpp
+++ b/kmail/treebase.cpp
@@ -27,9 +27,9 @@
using namespace KMail;
-TreeBase::TreeBase( TQWidget *tqparent, KMFolderTree *folderTree,
+TreeBase::TreeBase( TQWidget *parent, KMFolderTree *folderTree,
const TQString &preSelection, bool mustBeReadWrite )
- : KListView( tqparent ), mFolderTree( folderTree )
+ : KListView( parent ), mFolderTree( folderTree )
{
Q_UNUSED( preSelection );
Q_UNUSED( mustBeReadWrite );
@@ -116,13 +116,13 @@ void TreeBase::recolorRows()
TQListViewItem * item = it.current() ;
if ( item->isVisible() ) {
bool visible = true;
- TQListViewItem * tqparent = item->tqparent();
- while ( tqparent ) {
- if (!tqparent->isOpen()) {
+ TQListViewItem * parent = item->parent();
+ while ( parent ) {
+ if (!parent->isOpen()) {
visible = false;
break;
}
- tqparent = tqparent->tqparent();
+ parent = parent->parent();
}
if ( visible ) {
@@ -174,7 +174,7 @@ void TreeBase::reload( bool mustBeReadWrite, bool showOutbox, bool showImapFolde
}
else {
if ( depth > lastDepth ) {
// next lower level - tqparent node will get opened
item = createItem( lastItem );
lastItem->setOpen( true );
}
@@ -183,15 +183,15 @@ void TreeBase::reload( bool mustBeReadWrite, bool showOutbox, bool showImapFolde
path = path.section( '/', 0, -2 - (lastDepth-depth) );
if ( depth == lastDepth )
// same level - behind previous item
- item = createItem( lastItem->tqparent(), lastItem );
+ item = createItem( lastItem->parent(), lastItem );
else if ( depth < lastDepth ) {
// above previous level - might be more than one level difference
// but highest possibility is top level
- while ( ( depth <= --lastDepth ) && lastItem->tqparent() ) {
- lastItem = static_cast<TQListViewItem *>( lastItem->tqparent() );
+ while ( ( depth <= --lastDepth ) && lastItem->parent() ) {
+ lastItem = static_cast<TQListViewItem *>( lastItem->parent() );
}
- if ( lastItem->tqparent() )
- item = createItem( lastItem->tqparent(), lastItem );
+ if ( lastItem->parent() )
+ item = createItem( lastItem->parent(), lastItem );
else {
// chain somehow broken - what does cause this ???
kdDebug( 5006 ) << "You shouldn't get here: depth=" << depth
@@ -174,7 +174,7 @@ void TreeBase::reload( bool mustBeReadWrite, bool showOutbox, bool showImapFolde
else {
if ( depth > lastDepth ) {
- // next lower level - tqparent node will get opened
+ // next lower level - parent node will get opened
item = createItem( lastItem );
lastItem->setOpen( true );